@@ -37,8 +37,8 @@ class Unique(val text: String, val sourceObjectType: UniqueTarget? = null, val s
 
     val allParams = params + conditionals.flatMap { it.params }
 
-    val isLocalEffect = params.contains("in this city")
-    val isAntiLocalEffect = params.contains("in other cities")
+    val isLocalEffect = params.contains("in this city") || conditionals.any { it.type == UniqueType.ConditionalInThisCity }
+    val isAntiLocalEffect = params.contains("in other cities") || conditionals.any { it.type == UniqueType.ConditionalInOtherCities }
 
     fun hasFlag(flag: UniqueFlag) = type != null && type.flags.contains(flag)
 
@@ -125,7 +125,7 @@ class Unique(val text: String, val sourceObjectType: UniqueTarget? = null, val s
     ): Boolean {
 
         val nonConditionalConditionTypes = setOf(UniqueTarget.TriggerCondition, UniqueTarget.UnitTriggerCondition, UniqueTarget.UnitActionModifier)
-        if (condition.type!!.targetTypes.any { it in nonConditionalConditionTypes })
+        if (condition.type?.targetTypes?.any { it in nonConditionalConditionTypes } == true)
             return true // not a filtering condition
 
         fun ruleset() = state.civInfo!!.gameInfo.ruleset
@@ -137,7 +137,7 @@ class Unique(val text: String, val sourceObjectType: UniqueTarget? = null, val s
 
         val relevantTile by lazy { state.attackedTile
             ?: state.tile
-            ?: state.unit?.getTile()
+            ?: relevantUnit?.getTile()
             ?: state.city?.getCenterTile()
         }
 
@@ -162,7 +162,7 @@ class Unique(val text: String, val sourceObjectType: UniqueTarget? = null, val s
             UniqueType.ConditionalWhenBelowAmountResource -> state.civInfo != null
                     && state.civInfo.getCivResourcesByName()[condition.params[1]]!! < condition.params[0].toInt()
             UniqueType.ConditionalHappy ->
-                state.civInfo != null && state.civInfo.stats.statsForNextTurn.happiness >= 0
+                state.civInfo != null && state.civInfo.stats.happiness >= 0
             UniqueType.ConditionalBetweenHappiness ->
                 state.civInfo != null
                 && condition.params[0].toInt() <= state.civInfo.stats.happiness
@@ -204,6 +204,8 @@ class Unique(val text: String, val sourceObjectType: UniqueTarget? = null, val s
             UniqueType.ConditionalBuildingBuilt ->
                 state.civInfo != null && state.civInfo.cities.any { it.cityConstructions.containsBuildingOrEquivalent(condition.params[0]) }
 
+            // Filtered via city.getMatchingUniques
+            UniqueType.ConditionalInThisCity -> true
             UniqueType.ConditionalCityWithBuilding ->
                 state.city != null && state.city.cityConstructions.containsBuildingOrEquivalent(condition.params[0])
             UniqueType.ConditionalCityWithoutBuilding ->
@@ -215,7 +217,7 @@ class Unique(val text: String, val sourceObjectType: UniqueTarget? = null, val s
 
             UniqueType.ConditionalVsCity -> state.theirCombatant?.matchesCategory("City") == true
             UniqueType.ConditionalVsUnits -> state.theirCombatant?.matchesCategory(condition.params[0]) == true
-            UniqueType.ConditionalOurUnit ->
+            UniqueType.ConditionalOurUnit, UniqueType.ConditionalOurUnitOnUnit ->
                 relevantUnit?.matchesFilter(condition.params[0]) == true
             UniqueType.ConditionalUnitWithPromotion -> relevantUnit?.promotions?.promotions?.contains(condition.params[0]) == true
             UniqueType.ConditionalUnitWithoutPromotion -> relevantUnit?.promotions?.promotions?.contains(condition.params[0]) == false
@@ -299,8 +301,35 @@ class LocalUniqueCache(val cache:Boolean = true) {
     // This stores sequences *that iterate directly on a list* - that is, pre-resolved
     private val keyToUniques = HashMap<String, Sequence<Unique>>()
 
+    fun forCityGetMatchingUniques(
+        city: City,
+        uniqueType: UniqueType,
+        stateForConditionals: StateForConditionals = StateForConditionals(
+            city.civ,
+            city
+        )
+    ): Sequence<Unique> {
+        return get(
+            "city-${city.id}-${uniqueType.name}-${stateForConditionals}",
+            city.getMatchingUniques(uniqueType, stateForConditionals)
+        )
+    }
+
+    fun forCivGetMatchingUniques(
+        civ: Civilization,
+        uniqueType: UniqueType,
+        stateForConditionals: StateForConditionals = StateForConditionals(
+            civ
+        )
+    ): Sequence<Unique> {
+        return get(
+            "civ-${civ.civName}-${uniqueType.name}-${stateForConditionals}",
+            civ.getMatchingUniques(uniqueType, stateForConditionals)
+        )
+    }
+
     /** Get cached results as a sequence */
-    fun get(key: String, sequence: Sequence<Unique>): Sequence<Unique> {
+    private fun get(key: String, sequence: Sequence<Unique>): Sequence<Unique> {
         if (!cache) return sequence
         if (keyToUniques.containsKey(key)) return keyToUniques[key]!!
         // Iterate the sequence, save actual results as a list, as return a sequence to that
@@ -379,4 +408,3 @@ fun ArrayList<TemporaryUnique>.getMatchingUniques(uniqueType: UniqueType, stateF
             .map { it.uniqueObject }
             .filter { it.isOfType(uniqueType) && it.conditionalsApply(stateForConditionals) }
     }
-
